==> qtjambi-xml-6.2.12-sources.jar: io/qt/xml/QDomAttr.java <==
package io.qt.xml;

import io.qt.*;


/**
 * <p>Represents one attribute of a QDomElement</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qdomattr.html">QDomAttr</a></p>
 */
public class QDomAttr extends io.qt.xml.QDomNode
    implements java.lang.Cloneable
{
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomattr.html#QDomAttr">QDomAttr::QDomAttr()</a></p>
     */
    public QDomAttr(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QDomAttr instance);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomattr.html#QDomAttr-1">QDomAttr::QDomAttr(QDomAttr)</a></p>
     */
    public QDomAttr(io.qt.xml.@NonNull QDomAttr x){
        super((QPrivateConstructor)null);
        initialize_native(this, x);
    }
    
    private native static void initialize_native(QDomAttr instance, io.qt.xml.QDomAttr x);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomattr.html#name">QDomAttr::name()const</a></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String name(){
        return name_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String name_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomattr.html#operator-eq">QDomAttr::operator=(QDomAttr)</a></p>
     */
    @QtUninvokable
    public final void assign(io.qt.xml.@NonNull QDomAttr arg__1){
        assign_native_cref_QDomAttr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QDomAttr(long __this__nativeId, long arg__1);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomattr.html#ownerElement">QDomAttr::ownerElement()const</a></p>
     */
    @QtUninvokable
    public final io.qt.xml.@NonNull QDomElement ownerElement(){
        return ownerElement_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.xml.QDomElement ownerElement_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomattr.html#setValue">QDomAttr::setValue(QString)</a></p>
     */
    @QtUninvokable
    public final void setValue(java.lang.@NonNull String arg__1){
        setValue_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1);
    }
    
    @QtUninvokable
    private native void setValue_native_cref_QString(long __this__nativeId, java.lang.String arg__1);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomattr.html#specified">QDomAttr::specified()const</a></p>
     */
    @QtUninvokable
    public final boolean specified(){
        return specified_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean specified_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomattr.html#value">QDomAttr::value()const</a></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String value(){
        return value_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String value_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QDomAttr(QPrivateConstructor p) { super(p); } 
    
    
    @QtUninvokable
    @Override
    public QDomAttr clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QDomAttr clone_native(long __this_nativeId);
}

==> qtjambi-xml-6.3.3-sources.jar: io/qt/xml/QDomAttr.java <==
package io.qt.xml;


/**
 * <p>Represents one attribute of a QDomElement</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qdomattr.html">QDomAttr</a></p>
 */
public class QDomAttr extends io.qt.xml.QDomNode
    implements java.lang.Cloneable
{
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomattr.html#QDomAttr">QDomAttr::QDomAttr()</a></p>
     */
    public QDomAttr(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QDomAttr instance);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomattr.html#QDomAttr-1">QDomAttr::QDomAttr(QDomAttr)</a></p>
     */
    public QDomAttr(io.qt.xml.QDomAttr x){
        super((QPrivateConstructor)null);
        initialize_native(this, x);
    }
    
    private native static void initialize_native(QDomAttr instance, io.qt.xml.QDomAttr x);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomattr.html#name">QDomAttr::name()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String name(){
        return name_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String name_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomattr.html#ownerElement">QDomAttr::ownerElement()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.xml.QDomElement ownerElement(){
        return ownerElement_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.xml.QDomElement ownerElement_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomattr.html#setValue">QDomAttr::setValue(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setValue(java.lang.String arg__1){
        setValue_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1);
    }
    
    @io.qt.QtUninvokable
    private native void setValue_native_cref_QString(long __this__nativeId, java.lang.String arg__1);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomattr.html#specified">QDomAttr::specified()const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean specified(){
        return specified_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean specified_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomattr.html#value">QDomAttr::value()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String value(){
        return value_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String value_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QDomAttr(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QDomAttr clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QDomAttr clone_native(long __this_nativeId);
}
